@@ -8,7 +8,6 @@ import qualified Data.Data as D
 import Data.Data hiding (toConstr, typeOf, dataTypeOf, isAlgType)
 import Data.List
 import Data.Maybe
-import qualified Data.Typeable.Internal as I
 import System.IO.Unsafe
 
 
@@ -67,7 +66,7 @@ typeShell :: Any -> String
 typeShell = tyconUQname . typeShellFull
 
 typeShellFull :: Any -> String
-typeShellFull = I.tyConName . typeRepTyCon . typeOf
+typeShellFull = tyConName . typeRepTyCon . typeOf
 
 typeName :: Any -> String
 typeName = show . typeOf
