@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 
 module System.Console.CmdArgs.Explicit.Type where
 
@@ -7,6 +8,9 @@ import Data.Char
 import Data.List
 import Data.Maybe
 import Data.Monoid
+#if __GLASGOW_HASKELL__ >= 802
+import Data.Semigroup (Semigroup(..))
+#endif
 import Prelude
 
 
@@ -48,6 +52,11 @@ data Group a = Group
 instance Functor Group where
     fmap f (Group a b c) = Group (map f a) (map f b) (map (second $ map f) c)
 
+#if __GLASGOW_HASKELL__ > 800
+instance Semigroup (Group a) where
+    (<>) = mappend
+#endif
+
 instance Monoid (Group a) where
     mempty = Group [] [] []
     mappend (Group x1 x2 x3) (Group y1 y2 y3) = Group (x1++y1) (x2++y2) (x3++y3)
